==> invoice-client-4.1.5-20200206.054535-14-sources.jar: com/xforceplus/seller/invoice/client/model/PreInvoiceBackFillRequest.java <==
package com.xforceplus.seller.invoice.client.model;

import com.fasterxml.jackson.annotation.JsonInclude;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;

/**
 * @author <a href="mail to: libaozhong@xforceplus.com" rel="nofollow">libaozhong</a>
 * @Description: [功能描述]
 * @version: 1.0
 * @CreateDate: 2019-07-02 15:21</p>
 */

@ApiModel(description = "预制发票回填信息")
@JsonInclude(NON_NULL)
public class PreInvoiceBackFillRequest {
    @ApiModelProperty(value = "预制发票id",required = true)
    private Long preInvoiceId;
    @ApiModelProperty(value = "发票号码",required = true)
    private  String invoiceCode;
    @ApiModelProperty(value = "发票代码",required = true)
    private   String invoiceNo;
    @ApiModelProperty(value = "开票日期",required = true)
    private  String paperDrewDate;
    @ApiModelProperty(value = "机器码",required = true)
    private String machineCode;
    @ApiModelProperty(value = "校验码",required = true)
    private String checkCode;
    @ApiModelProperty(value = "密文",required = true)
    private String cipherText;
    @ApiModelProperty(value = "原发票号码",required = true)
    private String originInvoiceNo;
    @ApiModelProperty(value = "原发票代码",required = true)
    private String originInvoiceCode;
    @ApiModelProperty(value = "红字信息表编号",required = true)
    private String redNotificationNo;


    public Long getPreInvoiceId() {
        return preInvoiceId;
    }

    public void setPreInvoiceId(Long preInvoiceId) {
        this.preInvoiceId = preInvoiceId;
    }

    public String getInvoiceCode() {
        return invoiceCode;
    }

    public void setInvoiceCode(String invoiceCode) {
        this.invoiceCode = invoiceCode;
    }

    public String getInvoiceNo() {
        return invoiceNo;
    }

    public void setInvoiceNo(String invoiceNo) {
        this.invoiceNo = invoiceNo;
    }

    public String getPaperDrewDate() {
        return paperDrewDate;
    }

    public void setPaperDrewDate(String paperDrewDate) {
        this.paperDrewDate = paperDrewDate;
    }

    public String getMachineCode() {
        return machineCode;
    }

    public void setMachineCode(String machineCode) {
        this.machineCode = machineCode;
    }

    public String getCheckCode() {
        return checkCode;
    }

    public void setCheckCode(String checkCode) {
        this.checkCode = checkCode;
    }

    public String getCipherText() {
        return cipherText;
    }

    public void setCipherText(String cipherText) {
        this.cipherText = cipherText;
    }

    public String getOriginInvoiceNo() {
        return originInvoiceNo;
    }

    public void setOriginInvoiceNo(String originInvoiceNo) {
        this.originInvoiceNo = originInvoiceNo;
    }

    public String getOriginInvoiceCode() {
        return originInvoiceCode;
    }

    public void setOriginInvoiceCode(String originInvoiceCode) {
        this.originInvoiceCode = originInvoiceCode;
    }

    public String getRedNotificationNo() {
        return redNotificationNo;
    }

    public void setRedNotificationNo(String redNotificationNo) {
        this.redNotificationNo = redNotificationNo;
    }

    @Override
    public int hashCode() {
        return super.hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        return super.equals(obj);
    }

    @Override
    protected Object clone() throws CloneNotSupportedException {
        return super.clone();
    }

    @Override
    public String toString() {
        return super.toString();
    }
}

==> invoice-client-4.1.56-20240305.094845-14-sources.jar: com/xforceplus/seller/invoice/client/model/PreInvoiceBackFillRequest.java <==
package com.xforceplus.seller.invoice.client.model;

import com.fasterxml.jackson.annotation.JsonInclude;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import static com.fasterxml.jackson.annotation.JsonInclude.Include.NON_NULL;

/**
 * @author <a href="mail to: libaozhong@xforceplus.com" rel="nofollow">libaozhong</a>
 * @Description: [功能描述]
 * @version: 1.0
 * @CreateDate: 2019-07-02 15:21</p>
 */

@ApiModel(description = "预制发票回填信息")
@JsonInclude(NON_NULL)
@Data
public class PreInvoiceBackFillRequest {
    @ApiModelProperty(value = "租户Id",required = true)
    private Long sellerGroupId;
    @ApiModelProperty(value = "预制发票id",required = true)
    private Long preInvoiceId;
    @ApiModelProperty(value = "开票日期",required = true)
    private  String paperDrewDate;
    @ApiModelProperty(value = "发票代码")
    private  String invoiceCode;
    @ApiModelProperty(value = "发票号码",required = true)
    private   String invoiceNo;

    @ApiModelProperty(value = "数电发票号码")
    private String allElectricInvoiceNo;
    @ApiModelProperty(value = "密文",required = true)
    private String cipherText;
    @ApiModelProperty(value = "pdf地址",required = true)
    private String pdfUrl;
    @ApiModelProperty(value = "ofd地址",required = true)
    private String ofdUrl;
    @ApiModelProperty(value = "xml地址",required = true)
    private String xmlUrl;

    @ApiModelProperty(value = "校验码",required = true)
    private String checkCode;
    @ApiModelProperty(value = "机器码",required = true)
    private String machineCode;
    @ApiModelProperty(value = "开票人",required = true)
    private String invoicerName;
    @ApiModelProperty(value = "原发票号码",required = true)
    private String originInvoiceNo;
    @ApiModelProperty(value = "原发票代码",required = true)
    private String originInvoiceCode;
    @ApiModelProperty(value = "红字信息表编号",required = true)
    private String redNotificationNo;
}
